@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Measure the positive/negative sentiment of text
 
-our $VERSION = '0.0501';
+our $VERSION = '0.0502';
 
 use Moo;
 use strictures 2;
@@ -163,7 +163,7 @@ Lingua::EN::Opinion - Measure the positive/negative sentiment of text
 
 =head1 VERSION
 
-version 0.0501
+version 0.0502
 
 =head1 SYNOPSIS
 
@@ -184,6 +184,9 @@ NOTE: This module is 3.4MB because of the GIANT sentiment text it comes with.
 
 Please see the F<eg/> and F<t/> scripts for example usage.
 
+The write-up illustrating usage and results can be found at
+L<http://techn.ology.net/book-of-revelation-sentiment-analysis/>
+
 =head1 ATTRIBUTES
 
 =head2 file
